@@ -13,6 +13,7 @@ from talos.thrift.consumer.ttypes import UnlockPartitionRequest
 from talos.thrift.consumer.ttypes import LockPartitionRequest
 from talos.thrift.consumer.ttypes import LockPartitionResponse
 from talos.client.TalosClientFactory import ConsumerClient
+from talos.thrift.common.ttypes import GalaxyTalosException
 from talos.utils import Utils
 from talos.utils.Utils import synchronized
 import logging
@@ -38,20 +39,6 @@ class TASK_STATE:
     SHUTDOWNED = 4
 
 
-def cur_state_to_string(curState=None):
-    if curState == TASK_STATE.INIT:
-        return "INIT"
-    elif curState == TASK_STATE.LOCKED:
-        return "LOCKED"
-    elif curState == TASK_STATE.UNLOCKING:
-        return "UNLOCKING"
-    elif curState == TASK_STATE.UNLOCKED:
-        return "UNLOCKED"
-    elif curState == TASK_STATE.SHUTDOWNED:
-        return "SHUTDOWNED"
-    else:
-        return "UNKNOWNSTATE"
-
 #
 # PartitionFetcher
 #
@@ -73,18 +60,18 @@ class PartitionFetcher(object):
     partitionId = int
     workerId = str
     consumerClient = ConsumerClient
-    commitOffsetClient = ConsumerClient
     curState = int
     topicAndPartition = TopicAndPartition
     topicName = str
     simpleConsumer = SimpleConsumer
     messageReader = MessageReader
 
-    def __init__(self, consumerGroup=None, topicName=None, topicTalosResourceName=None,
-                 partitionId=None, talosConsumerConfig=None, workerId=None,
-                 consumerClient=None, messageClient=None, getPartitionOffsetClient=None,
-                 queryPartitionCleint=None, commitOffsetClient=None, messageProcessor=None,
-                 messageReader=None, simpleConsumer=None, outerCheckPoint=None):
+    def __init__(self, consumerGroup=None, topicName=None,
+                 topicTalosResourceName=None, partitionId=None,
+                 talosConsumerConfig=None, workerId=None,
+                 consumerClient=None, messageClient=None,
+                 messageProcessor=None, messageReader=None,
+                 simpleConsumer=None, outerCheckPoint=None):
         self.synchronizedLock = threading.Lock()
         self.consumerGroup = consumerGroup
         self.topicTalosResourceName = topicTalosResourceName
@@ -103,9 +90,6 @@ class PartitionFetcher(object):
             self.simpleConsumer = SimpleConsumer(talosConsumerConfig,
                                                  topicAndPartition=self.topicAndPartition,
                                                  messageClient=messageClient)
-        self.getPartitionOffsetClient = getPartitionOffsetClient
-        self.queryPartitionClient = queryPartitionCleint
-        self.commitOffsetClient = commitOffsetClient
 
         self.fetcherStateMachine = threading.Thread
 
@@ -117,9 +101,7 @@ class PartitionFetcher(object):
             self.messageReader.set_topic_and_partition(self.topicAndPartition)
             self.messageReader.set_simple_consumer(self.simpleConsumer)
             self.messageReader.set_message_processor(messageProcessor)
-            self.messageReader.set_message_client(self.getPartitionOffsetClient)
-            self.messageReader.set_consumer_client(self.commitOffsetClient)
-            self.messageReader.set_query_offset_client(self.queryPartitionClient)
+            self.messageReader.set_consumer_client(self.consumerClient)
             self.messageReader.set_outer_checkpoint(outerCheckPoint)
 
         self.logger.info("The PartitionFetcher for topic: " +
@@ -139,6 +121,8 @@ class PartitionFetcher(object):
         try:
             self.messageReader.init_start_offset()
         except Exception as e:
+            if isinstance(e, GalaxyTalosException):
+                self.logger.error(e.errMsg)
             self.logger.error("Worker: " + self.workerId + " query partition offset " +
                               "error: we will skip this partition" + str(traceback.format_exc()))
             self.clean()
@@ -197,8 +181,8 @@ class PartitionFetcher(object):
     @synchronized
     def update_state(self, targetState=None):
         self.logger.info("PartitionFetcher for Partition: " + str(self.partitionId)
-                         + " update " + "status from: " + cur_state_to_string(self.curState)
-                         + " to: " + cur_state_to_string(targetState))
+                         + " update " + "status from: " + str(self.curState) + " to: "
+                         + str(targetState))
         if targetState == TASK_STATE.INIT:
             self.logger.error("targetState can nerver be INIT, "
                               + "updateState error for: " + str(self.partitionId))
@@ -208,7 +192,7 @@ class PartitionFetcher(object):
                 self.curState = TASK_STATE.LOCKED
                 return True
             self.logger.error("targetState is LOCKED, but curState is: "
-                              + cur_state_to_string(self.curState) + " for partition: "
+                              + str(self.curState) + " for partition: "
                               + str(self.partitionId))
             return False
         elif targetState == TASK_STATE.UNLOCKING:
@@ -216,7 +200,7 @@ class PartitionFetcher(object):
                 self.curState = TASK_STATE.UNLOCKING
                 return True
             self.logger.error("targetState is UNLOCKING, but curState is: "
-                              + cur_state_to_string(self.curState) + " for partition: "
+                              + str(self.curState) + " for partition: "
                               + str(self.partitionId))
             return False
         elif targetState == TASK_STATE.UNLOCKED:
@@ -224,7 +208,7 @@ class PartitionFetcher(object):
                 self.curState = TASK_STATE.UNLOCKED
                 return True
             self.logger.error("targetState is UNLOCKED, but curState is: "
-                              + cur_state_to_string(self.curState) + " for partition: "
+                              + str(self.curState) + " for partition: "
                               + str(self.partitionId))
             return False
         elif targetState == TASK_STATE.SHUTDOWNED:
@@ -247,6 +231,8 @@ class PartitionFetcher(object):
         try:
             self.consumerClient.unlock_partition(unlockRequest)
         except Exception as e:
+            if isinstance(e, GalaxyTalosException):
+                self.logger.error(e.errMsg)
             self.logger.warn("Worker: " + self.workerId + " release partition error: "
                              + str(traceback.format_exc()))
             return
@@ -270,6 +256,8 @@ class PartitionFetcher(object):
         try:
             lockResponse = self.consumerClient.lock_partition(lockRequest)
         except Exception as e:
+            if isinstance(e, GalaxyTalosException):
+                self.logger.error(e.errMsg)
             self.logger.error("Worker: " + self.workerId + " steal partition id : "
                               + str(self.partitionId) + " error! " + str(traceback.format_exc()))
             return False
@@ -294,7 +282,6 @@ class PartitionFetcher(object):
     def shutdown(self):
         # set UNLOCKING to stop read and wait fetcher gracefully quit
         self.update_state(TASK_STATE.UNLOCKING)
-        self.fetcherStateMachine.join()
         self.update_state(TASK_STATE.SHUTDOWNED)
 
 
