@@ -9,10 +9,8 @@ from talos.thrift.topic.ttypes import TopicTalosResourceName
 from talos.admin.TalosAdmin import TalosAdmin
 from talos.client.TalosClientConfig import TalosClientConfig
 from talos.client.TalosClientFactory import TalosClientFactory
-from talos.client.ScheduleInfoCache import ScheduleInfoCache
 from talos.utils import Utils
 from talos.utils.Utils import ReadWriteLock
-from talos.utils.FalconWriter import FalconWriter
 from talos.consumer.MessageProcessorFactory import MessageProcessorFactory
 from talos.consumer.MessageReaderFactory import MessageReaderFactory
 from talos.thrift.consumer.ttypes import ConsumeUnit
@@ -22,7 +20,7 @@ from talos.thrift.consumer.ttypes import RenewRequest
 from talos.thrift.consumer.ttypes import LockWorkerRequest
 from talos.client.TalosErrors import InvalidArgumentError
 from talos.consumer.PartitionFetcher import PartitionFetcher
-from talos.client.TalosClientFactory import ConsumerClient
+from talos.thrift.common.ttypes import GalaxyTalosException
 from threading import Timer
 import logging
 import random
@@ -55,11 +53,10 @@ class TalosConsumer(object):
     consumerGroup = str
     messageProcessorFactory = MessageProcessorFactory
     messageReaderFactory = MessageReaderFactory
-    partitionFetcherMap = dict
+    partitionFetcherMap = dict()
     talosConsumerConfig = TalosClientConfig
     talosClientFactory = TalosClientFactory
     talosAdmin = TalosAdmin
-    consumerClient = ConsumerClient
     readWriteLock = ReadWriteLock()
     isActive = bool
     reBalanceExecutor = threading.Thread
@@ -79,9 +76,6 @@ class TalosConsumer(object):
     workerInfoMap = dict
     partitionCheckPoint = dict
 
-    falconWriter = FalconWriter
-    consumerMonitorThread = Timer
-
     def __init__(self, consumerGroup=None, consumerConfig=None,
                  credential=None, topicName=None, messageProcessorFactory=None,
                  clientPrefix=None, talosResourceName=None, workerId=None,
@@ -106,8 +100,8 @@ class TalosConsumer(object):
         else:
             self.consumerClient = self.talosClientFactory.new_consumer_client()
             self.lockClient = self.talosClientFactory.new_consumer_client()
-            self.renewWorkerClient = self.talosClientFactory.new_consumer_client()
-            self.queryWorkerClient = self.talosClientFactory.new_consumer_client()
+            self.renewClient = self.talosClientFactory.new_consumer_client()
+            self.queryClient = self.talosClientFactory.new_consumer_client()
         if talosResourceName:
             self.topicTalosResourceName = talosResourceName
         else:
@@ -115,19 +109,10 @@ class TalosConsumer(object):
                 GetDescribeInfoRequest(self.topicName))
         if fetcherMap:
             self.partitionFetcherMap = fetcherMap
-        else:
-            self.partitionFetcherMap = dict()
         if partitionCheckPoint:
             self.partitionCheckPoint = partitionCheckPoint
         else:
             self.partitionCheckPoint = dict()
-        # get scheduleInfo
-        self.scheduleInfoCache = ScheduleInfoCache().get_schedule_info_cache(
-            topicTalosResourceName=self.topicTalosResourceName.topicTalosResourceName,
-            talosClientConfig=consumerConfig,
-            messageClient=self.talosClientFactory.new_message_client(),
-            talosClientFactory=self.talosClientFactory)
-        self.falconWriter = FalconWriter(falconUrl=consumerConfig.get_falcon_url())
         self.isActive = True
 
         logger.info("The worker: " + self.workerId + " is initializing...")
@@ -143,7 +128,6 @@ class TalosConsumer(object):
         self.init_check_partition_task()
         self.init_check_worker_info_task()
         self.init_renew_task()
-        self.init_consumer_monitor_task()
 
     #
     # Check Partition Task
@@ -189,14 +173,13 @@ class TalosConsumer(object):
             self.set_partition_number(topicPartitionNum)
             # call the re - balance task
             self.reBalanceExecutor = threading.Thread(target=self.re_balance_task)
-            self.reBalanceExecutor.setName("talos-consumer-reBalanceTask-" + self.topicName)
+            self.reBalanceExecutor.setName("reBalanceTask-" + self.topicName)
             self.reBalanceExecutor.start()
 
         self.partitionScheduledExecutor = Timer(interval=self.talosConsumerConfig
                                                 .get_check_partition_interval(),
                                                 function=self.check_partition_task)
-        self.partitionScheduledExecutor.setName("talos-consumer-checkPartitionTask-"
-                                                + self.topicName)
+        self.partitionScheduledExecutor.setName("checkPartitionTask-" + self.topicName)
         self.partitionScheduledExecutor.start()
 
     #
@@ -227,8 +210,7 @@ class TalosConsumer(object):
         self.workerScheduleExecutor = Timer(interval=self.talosConsumerConfig
                                             .get_check_worker_info_interval(),
                                             function=self.check_worker_info_task)
-        self.workerScheduleExecutor.setName("talos-consumer-checkWorkerInfoTask-"
-                                            + self.topicName)
+        self.workerScheduleExecutor.setName("checkWorkerInfoTask-" + self.topicName)
         self.workerScheduleExecutor.start()
 
     #
@@ -263,9 +245,12 @@ class TalosConsumer(object):
         maxRetry = self.talosConsumerConfig.get_renew_max_retry() + 1
         while maxRetry > 0:
             try:
-                renewResponse = self.renewWorkerClient.renew(renewRequest)
+                renewResponse = self.renewClient.renew(renewRequest)
             except Exception as e:
-                logger.error("Worker: " + self.workerId + " renew error: " + str(traceback.format_exc()))
+                if isinstance(e, GalaxyTalosException):
+                    logger.error(e.errMsg)
+                logger.error("Worker: " + self.workerId + " renew error: "
+                             + str(traceback.format_exc()))
                 continue
             maxRetry -= 1
 
@@ -288,38 +273,27 @@ class TalosConsumer(object):
         # do not block the renew thread and switch thread to re-balance thread
         if renewResponse and len(renewResponse.failedPartitionList) > 0:
             failedRenewList = renewResponse.failedPartitionList
-            logger.error("The worker: " + self.workerId + " failed to renew partitions: "
-                         + str(failedRenewList))
+            logger.error("The worker: " + self.workerId + " failed to renew partitions: " + str(failedRenewList))
             self.release_partition_lock(failedRenewList)
 
         self.renewScheduleExecutor = Timer(interval=self.talosConsumerConfig
                                            .get_renew_check_interval(),
                                            function=self.renew_task)
-        self.renewScheduleExecutor.setName("talos-consumer-renewTask-" + self.topicName)
+        self.renewScheduleExecutor.setName("renewTask-" + self.topicName)
         self.renewScheduleExecutor.start()
 
-    def consumer_monitor_task(self):
-        try:
-            self.push_metric_data()
-        except Exception as throwable:
-            logger.error("push metric data to falcon failed." + str(traceback.format_exc()))
-
-        self.consumerMonitorThread = Timer(interval=self.talosConsumerConfig
-                                           .get_report_metric_interval_millis() / 1000,
-                                           function=self.consumer_monitor_task)
-        self.consumerMonitorThread.setName("talos-consumer-checkPartitionTask-"
-                                           + self.topicName)
-        self.consumerMonitorThread.start()
-
     def check_and_get_topic_info(self, topicTalosResourceName=None):
         topicName = Utils.get_topic_name_by_resource_name(
             str(topicTalosResourceName.topicTalosResourceName.topicTalosResourceName))
         response = self.talosAdmin.get_describe_info(GetDescribeInfoRequest(topicName))
-        resourceName = topicTalosResourceName.topicTalosResourceName.topicTalosResourceName
 
-        if not resourceName == response.topicTalosResourceName.topicTalosResourceName:
+        if not topicTalosResourceName.topicTalosResourceName.topicTalosResourceName ==\
+               response.topicTalosResourceName.topicTalosResourceName:
             logger.info("The consumer initialize failed by topic not found")
-            raise InvalidArgumentError("The topic: " + resourceName + " not found")
+            raise InvalidArgumentError("The topic: " + str(topicTalosResourceName.
+                                                           topicTalosResourceName.
+                                                           topicTalosResourceName) +
+                                       " not found")
 
         self.set_partition_number(response.partitionNumber)
         self.topicTalosResourceName = topicTalosResourceName.topicTalosResourceName
@@ -340,6 +314,8 @@ class TalosConsumer(object):
             try:
                 lockWorkerResponse = self.lockClient.lock_worker(lockWorkerRequest)
             except Exception as e:
+                if isinstance(e, GalaxyTalosException):
+                    logger.error(e.errMsg)
                 logger.error("The worker: " + self.workerId + "register self got error: "
                              + str(traceback.format_exc()))
                 continue
@@ -356,7 +332,7 @@ class TalosConsumer(object):
     def get_worker_info(self):
         queryWorkerRequest = QueryWorkerRequest(self.consumerGroup,
                                                 self.topicTalosResourceName)
-        queryWorkerResponse = self.queryWorkerClient.query_worker(queryWorkerRequest)
+        queryWorkerResponse = self.queryClient.query_worker(queryWorkerRequest)
 
         # if queryWorkerInfoMap size equals 0,
         # it represents hbase failed error, do not update local map
@@ -385,8 +361,8 @@ class TalosConsumer(object):
         else:
             # calculate the target sequence
             sum = 0
-            min = copyPartitionNum / workerNumber
-            remainder = copyPartitionNum % workerNumber
+            min = int(copyPartitionNum / workerNumber)
+            remainder = int(copyPartitionNum % workerNumber)
             # add max by remainder
             index = 0
             while index < remainder:
@@ -449,7 +425,7 @@ class TalosConsumer(object):
                 has = len(hasList)
 
                 # workerNum > partitionNum, idle workers have no match target, do nothing
-                if i >= len(targetList):
+                if i > len(targetList):
                     break
                 target = targetList[i]
                 if logger.isEnabledFor(logging.DEBUG):
@@ -502,9 +478,6 @@ class TalosConsumer(object):
                                                     workerId=self.workerId,
                                                     consumerClient=self.talosClientFactory.new_consumer_client(),
                                                     messageClient=self.talosClientFactory.new_message_client(),
-                                                    getPartitionOffsetClient=self.talosClientFactory.new_message_client(),
-                                                    queryPartitionCleint=self.talosClientFactory.new_consumer_client(),
-                                                    commitOffsetClient=self.talosClientFactory.new_consumer_client(),
                                                     messageProcessor=self.messageProcessorFactory.create_processor(),
                                                     messageReader=self.messageReaderFactory.create_message_reader(self.talosConsumerConfig),
                                                     outerCheckPoint=self.partitionCheckPoint.get(partitionId))
@@ -577,52 +550,31 @@ class TalosConsumer(object):
         self.partitionScheduledExecutor = Timer(interval=self.talosConsumerConfig
                                                 .get_check_partition_interval(),
                                                 function=self.check_partition_task)
-        self.partitionScheduledExecutor.setName("talos-consumer-checkPartitionTask-" + self.topicName)
+        self.partitionScheduledExecutor.setName("checkPartitionTask-" + self.topicName)
         self.partitionScheduledExecutor.start()
 
     def init_check_worker_info_task(self):
         self.workerScheduleExecutor = Timer(interval=self.talosConsumerConfig
                                             .get_check_worker_info_interval(),
                                             function=self.check_worker_info_task)
-        self.workerScheduleExecutor.setName("talos-consumer-checkWorkerInfoTask-" + self.topicName)
+        self.workerScheduleExecutor.setName("checkWorkerInfoTask-" + self.topicName)
         self.workerScheduleExecutor.start()
 
     def init_renew_task(self):
         self.renewScheduleExecutor = Timer(interval=self.talosConsumerConfig
                                            .get_renew_check_interval(),
                                            function=self.renew_task)
-        self.renewScheduleExecutor.setName("talos-consumer-renewTask-" + self.topicName)
+        self.renewScheduleExecutor.setName("renewTask-" + self.topicName)
         self.renewScheduleExecutor.start()
 
-    def init_consumer_monitor_task(self):
-        if self.talosConsumerConfig.is_open_client_monitor():
-            self.consumerMonitorThread = Timer(interval=self.talosConsumerConfig
-                                               .get_report_metric_interval_millis() / 1000,
-                                               function=self.consumer_monitor_task)
-            self.consumerMonitorThread.setName("talos-consumer-monitor-" + self.topicName)
-            self.consumerMonitorThread.start()
-
-    def push_metric_data(self):
-        jsonArray = []
-        for key, value in self.partitionFetcherMap.items():
-            jsonArray += value.get_falcon_data()
-        self.falconWriter.push_falcon_data(jsonArray)
-
     #
     # First stop CheckPartition and CheckWorkerInfo Task and then shutdown all fetcher,
     # that avoid thread exit failed caused by rebalance partition when shutDownAllFetcher
     #
     def shutdown(self):
-        if not self.isActive:
-            logger.info("Worker: " + str(self.workerId) + " is already shutdown, "
-                        + "don't do it again.")
-            return
         logger.info("Worker: " + self.workerId + " is shutting down...")
         self.partitionScheduledExecutor.cancel()
         self.workerScheduleExecutor.cancel()
         self.shut_down_fetcher()
         self.renewScheduleExecutor.cancel()
-        self.consumerMonitorThread.cancel()
-        self.scheduleInfoCache.shut_down(self.topicTalosResourceName)
-        self.isActive = False
         logger.info("Worker: " + self.workerId + " shutdown.")
