@@ -56,10 +56,12 @@ class MessageWriter(threading.Thread):
 
                 self.partitionSender.put_message(messageList, self.simpleProducer)
             except Exception as e:
+                if isinstance(e, GalaxyTalosException):
+                    self.partitionSender.logger.error(e.errMsg)
                 self.partitionSender.logger.error(
                     "PutMessageTask for topicAndPartition: " +
                     str(self.partitionSender.topicAndPartition)
-                    + " failed" + e.message)
+                    + " failed" + str(traceback.format_exc()))
             finally:
                 # notify to wake up producer's global lock
                 with self.synchronizedLock:
@@ -86,6 +88,8 @@ class MessageCallbackTask(threading.Thread):
 class PartitionSender:
     logger = logging.getLogger("PartitionSender")
 
+    lock = threading.Lock()
+
     def __init__(self, partitionId=None, topicName=None, topicTalosResourceName=None,
                  requestId=None, clientId=None, talosProducerConfig=None,
                  messageClient=None, userMessageCallback=None, messageCallbackExecutors=None,
@@ -109,9 +113,11 @@ class PartitionSender:
                                                    partitionId)
         self.partitionMessageQueue = PartitionMessageQueue(talosProducerConfig,
                                                            partitionId, producer)
-        self.singleExecutor = ThreadPoolExecutor(max_workers=1, thread_name_prefix="talos-producer-" +
-                                                                                   self.topicAndPartition.topicName
-                                                                                   + " " + str(self.topicAndPartition.partitionId))
+        self.singleExecutor = ThreadPoolExecutor(
+            max_workers=1, thread_name_prefix="talos-producer-" +
+                                              self.topicAndPartition.topicName
+                                              + " " + str(self.topicAndPartition.partitionId))
+
         self.executor = MessageWriter(self, self.globalLock)
         self.executor.start()
 
@@ -133,14 +139,12 @@ class PartitionSender:
                 simpleProducer.do_put(messageList)
                 # putMessage success callback
                 userMessageResult.set_successful(True)
-                # self.messageCallbackExecutors = threading.Thread(
-                #     target=self.message_callback_task, args=(userMessageResult, ))
                 self.messageCallbackExecutors = MessageCallbackTask(userMessageResult,
                                                                     self.userMessageCallback)
                 self.messageCallbackExecutors.start()
                 if self.logger.isEnabledFor(logging.DEBUG):
-                    self.logger.debug("put " + str(len(messageList))
-                                      + " message success for partition: "
+                    self.logger.debug("put " + messageList.size() +
+                                      " message success for partition: "
                                       + str(self.partitionId))
         except Exception as e:
             # 1. backoff sleep and retry according to configuration
@@ -155,9 +159,6 @@ class PartitionSender:
             # execute putMessage failed callback when all retry failed
             userMessageResult.set_successful(False)
             userMessageResult.set_cause(e)
-            # self.messageCallbackExecutors = threading.Thread(
-            #     target=self.message_callback_task,
-            #     args=(self, userMessageResult))
             self.messageCallbackExecutors = MessageCallbackTask(userMessageResult,
                                                                 self.userMessageCallback)
             self.messageCallbackExecutors.start()
@@ -166,8 +167,11 @@ class PartitionSender:
                     self.logger.error(message.sequenceNumber + ": " + str(message.message))
 
             if not Utils.is_partition_not_serving(e):
+                if isinstance(e, GalaxyTalosException):
+                    self.logger.error(e.errMsg)
                 self.logger.error("Failed to put " + str(len(userMessageResult.get_message_list())) +
-                                  " messages for partition: " + str(self.partitionId) + e.message)
+                                  " messages for partition: " + str(self.partitionId)
+                                  + str(traceback.format_exc()) )
 
     def retry_put_message(self, e=None, userMessageResult=None, simpleProducer=None):
         if self.talosProducerConfig.get_max_retry() <= 0:
@@ -180,7 +184,7 @@ class PartitionSender:
             if self.logger.isEnabledFor(logging.DEBUG):
                 self.logger.warn("putMessage failed " + str(retry) +
                                  " times for partition: " + str(self.partitionId) +
-                                 ", sleep " + str(pauseTime) +
+                                 ", sleep " + pauseTime +
                                  "ms for avoid infinitely retry." + e.message)
             # 1. sleep
             Utils.sleep_pause_time(pauseTime)
@@ -189,16 +193,13 @@ class PartitionSender:
             try:
                 simpleProducer.do_put(userMessageResult.get_message_list())
                 userMessageResult.set_successful(True)
-                # self.messageCallbackExecutors = threading.Thread(
-                #     target=self.message_callback_task,
-                #     args=(self, userMessageResult))
                 self.messageCallbackExecutors = MessageCallbackTask(userMessageResult,
                                                                     self.userMessageCallback)
                 self.messageCallbackExecutors.start()
                 return True
-            except Exception as ex:
-                if isinstance(ex, GalaxyTalosException):
-                    self.logger.error(ex.errMsg)
+            except Exception as e:
+                if isinstance(e, GalaxyTalosException):
+                    self.logger.error(e.errMsg)
                 self.logger.error("retry put message failed. " + str(traceback.format_exc()))
 
             # 3. clear messageQueue when retry > 10 and partition buffer size > 10MB
@@ -216,8 +217,6 @@ class PartitionSender:
             self.topicAndPartition.topicName(), self.partitionId)
         bufferedUserMsgResult.set_successful(False)
         bufferedUserMsgResult.set_cause(e)
-        # self.messageCallbackExecutors = threading.Thread(
-        #     target=self.message_callback_task, args=(self, bufferedUserMsgResult))
         self.messageCallbackExecutors = MessageCallbackTask(bufferedUserMsgResult,
                                                             self.userMessageCallback)
         self.messageCallbackExecutors.start()
@@ -238,9 +237,6 @@ class PartitionSender:
                                            " do callback when shutdown this partitionSender."
             galaxyTalosException.errMsg = str(self.topicAndPartition) + "'s buffer not empty"
             userMessageResult.set_cause(galaxyTalosException)
-            # self.messageCallbackExecutors = threading.Thread(
-            #     target=self.message_callback_task,
-            #     args=(self, userMessageResult))
             self.messageCallbackExecutors = MessageCallbackTask(userMessageResult,
                                                                 self.userMessageCallback)
             self.messageCallbackExecutors.start()
@@ -249,7 +245,6 @@ class PartitionSender:
         # notify PartitionMessageQueue::getMessageList return;
         self.add_message([])
         self.update_state(TASK_STATE.CLOSE)
-#        self.singleExecutor.shutdown(True)
         self.executor.join()
         self.logger.info("PartitionSender for partition: "
                          + str(self.topicAndPartition.partitionId) + " finish stop")
